@@ -331,6 +331,8 @@ function db_query_parsed($sql, $ignore_errors = 0, $attach_mysql = "") {
         if ($debug) {
             echo_out("<div style='color:#f00'>" . $e->getMessage() . "</div>");
         }
+
+        throw new \Exception("Postfixadmin DB update failed. Please check your PHP error_log");
     }
 }
 /**
@@ -1386,7 +1388,11 @@ function upgrade_730_pgsql() {
     $table_quota = table_by_key('quota');
     $table_quota2 = table_by_key('quota2');
 
-    db_query_parsed('CREATE LANGUAGE plpgsql', 1); /* will error if plpgsql is already installed */
+    try {
+        db_query_parsed('CREATE LANGUAGE plpgsql', 1); /* will error if plpgsql is already installed */
+    } catch (\Exception $e) {
+        error_log("ignoring exception that's probably : plpgsql is probably already installed; " . $e);
+    }
 
     # trigger for dovecot v1.0 & 1.1 quota table
     # taken from http://wiki.dovecot.org/Quota/Dict
@@ -1823,9 +1829,7 @@ function upgrade_1836_mysql() {
  * @return void
  */
 function upgrade_1837() {
-    global $CONF;
-
-    if ($CONF['database_type'] == 'sqlite') {
+    if (db_sqlite()) {
         return;
     }
     # alternative contact means to reset a forgotten password
@@ -1920,6 +1924,14 @@ function upgrade_1841_sqlite() {
  * @return void
  */
 function upgrade_1842() {
+    $domain = table_by_key('domain');
+
+    // See: https://github.com/postfixadmin/postfixadmin/issues/489
+    // Avoid : ERROR 1292 (22007): Incorrect datetime value: '0000-00-00 00:00:00' for column 'created' at row 1
+    if (db_mysql()) {
+        db_execute("UPDATE $domain SET created='2000-01-01 00:00:00', modified='2000-01-01 00:00:00' WHERE domain='ALL'", [], true);
+    }
+
     _db_add_field('mailbox', 'password_expiry', "{DATETIME}"); // when a specific mailbox password expires
     _db_add_field('domain',  'password_expiry', 'int DEFAULT 0'); // expiry applied to mailboxes within that domain
 }
@@ -1931,3 +1943,17 @@ function upgrade_1843() {
     # Additional field for fetchmail to allow server with non-standard port number
     _db_add_field('fetchmail', 'src_port', "{INT}", 'src_server');
 }
+
+
+/**
+ * @return void
+ */
+function upgrade_1844() {
+    # See:https://github.com/postfixadmin/postfixadmin/issues/475 - add pkey to domain_admins.
+
+    if (db_sqlite()) {
+        return;
+    }
+
+    _db_add_field('domain_admins', 'id', '{AUTOINCREMENT} {PRIMARY}');
+}
